Supybot is a robust (it doesn't crash), user friendly (it's easy to
configure) and programmer friendly (plugins are *extremely* easy to
write) Python IRC bot.  It aims to be an adequate replacement for most
existing IRC bots.  It includes a very flexible and powerful ACL system
for controlling access to commands, as well as more than 50 builtin plugins
providing around 400 actual commands.

Limnoria is the project which continues development of Supybot since 2010.

# Build status

Master branch: [![Build Status (master branch)](https://travis-ci.org/ProgVal/Limnoria.png?branch=master)](https://travis-ci.org/ProgVal/Limnoria)

Testing branch: [![Build Status (testing branch)](https://travis-ci.org/ProgVal/Limnoria.png?branch=testing)](https://travis-ci.org/ProgVal/Limnoria)

Limnoria supports CPython 3.4, 3.5, 3.6, 3.7, 3.8, nightly;
and Pypy 3.

# Support

## Documentation

If this is your first install, there is an [install guide](https://docs.limnoria.net/en/latest/use/install.html).
You will probably be pointed to it if you ask on IRC how to install
Limnoria.
TL;DR version:

```
sudo apt-get install python3 python3-pip python3-wheel
pip3 install --user limnoria
# You might need to add $HOME/.local/bin to your PATH
supybot-wizard
```

There is extensive documentation at [docs.limnoria.net] and at
[Gribble wiki]. We took the time to write it; you should take the time to
read it.

[docs.limnoria.net]:https://docs.limnoria.net/
[Gribble wiki]:https://sourceforge.net/p/gribble/wiki/Main_Page/

## IRC channels

### In English

If you have any trouble, feel free to swing by [#limnoria](ircs://chat.freenode.net:6697/#limnoria) on
[freenode](https://freenode.net/) and ask questions.  We'll be happy to help
wherever we can.  And by all means, if you find anything hard to
understand or think you know of a better way to do something,
*please* post it on the [issue tracker] so we can improve the bot!

[issue tracker]:https://github.com/ProgVal/Limnoria/issues

### In Other languages

Only in French at the moment, located at [#supybot-fr on freenode](ircs://chat.freenode.net:6697/#supybot-fr).

